@@ -1,9 +1,10 @@
 package App::gh;
 use warnings;
 use strict;
-our $VERSION = '0.553';
+our $VERSION = '0.56';
 use App::gh::Config;
 use App::gh::API;
+use Cwd;
 require App::gh::Git;
 
 sub config {
@@ -14,6 +15,10 @@ sub api {
     return "App::gh::API";
 }
 
+sub git {
+    return App::gh::Git->repository;
+}
+
 __END__
 
 =head1 NAME
